# -*- coding: utf-8 -*-
import mrrapi

demo = mrrapi.api('','')

#print "Rig Detail 6899"
#print demo.rig_detail(7280)
#print "List Scrypt rigs over 10 MH"
#a= demo.rig_list(10,0,0,0,order='price',orderdir='desc')
#print a['data']['records']
#print "List X11 rigs"
#print demo.rig_list(0,0,0,0,'x11')
#print "Get my rigs"
#print demo.myrigs()

#print demo.rig_update(6899,rigName='bob bub',hashrate=57.2,rigStatus='DiSabled')
c = 2**1024
d = 98 * 10**6
e = c/d

print demo.getbalance()

#print demo.rental_detail('123110')
#3055 sha, 700 scrypt

#a = demo.list_profiles()
#print a
#for x in a['data']:
#    print x['name']
#    print x
a = demo.rig_list(0,0,0,0.000000014,"sha256")
print a

#b = demo.rent_rig(700,3,12259)
#print b



# -*- coding: utf-8 -*-
""" This module will interface with the MiningRigRentals.com API in an attempt to give you easy access to their api.
# Based off of https://github.com/matveyco/cex.io-api-python
# Modified for MiningRigRentals.com purposes
# Get a key from https://www.miningrigrentals.com/account/apikey
# Licensed The MIT License
"""

import hmac
import hashlib
import time
import urllib
import urllib2
import json
import sys

debug = False
__author__ = 'jcwoltz'
__version__ = '0.3.4'


class api:
    """ This class handles the work to talk to MRR's api
    """
    __api_key = ''
    __api_secret = ''
    __nonce_v = ''

    # Init class
    def __init__(self, api_key, api_secret):
        self.__api_key = api_key
        self.__api_secret = api_secret

    #get timestamp as nonce
    def __nonce(self):
        self.__nonce_v = '{:.10f}'.format(time.time() * 1000).split('.')[0]

    #generate signature
    def __signature(self, post_data):
        string = urllib.urlencode(post_data)  #url encode post data
        signature = hmac.new(self.__api_secret, string, digestmod=hashlib.sha1).hexdigest()  #create signature
        if debug:
            print "\n __signature"
            print string
            print signature
            print "\n"
        return signature

    def __post(self, url, param):  #Post Request (Low Level API call)
        params = urllib.urlencode(param)
        sign = self.__signature(param)
        req = urllib2.Request(url, params, {
            'User-agent': 'Mozilla/4.0 (compatible; MRR API Python client; ' + str(sys.platform) + '; ' + str(
                sys.version) + ')', 'x-api-key': self.__api_key, 'x-api-sign': sign})
        page = urllib2.urlopen(req).read()
        return page

    def api_call(self, target, param={}):  # api call (Middle level)
        url = 'https://www.miningrigrentals.com/api/v1/' + target  #generate url
        self.__nonce()
        param.update({'nonce': self.__nonce_v})
        answer = self.__post(url, param)  #Post Request
        return json.loads(answer)  # generate dict and return

    def getbalance(self):
        """
        Get the confirmed and unconfirmed balance form MRR
        :return: return confirmed and unconfirmed balances
        """
        return self.api_call('account', {'method': 'balance'})

    def myrigs(self):
        """
        :return: return list of rigs you own with detail
        """
        return self.api_call('account', {'method': 'myrigs'})

    def myrentals(self):
        """
        :return: return list of rigs you are actively renting
        """
        return self.api_call('account', {'method': 'myrentals'})

    def list_profiles(self):
        """
        :return: returns list of pool profiles configured for your account
        """
        return self.api_call('account', {'method': 'profiles'})

    def rental_detail(self, rental_id):
        """
        :param rental_id: id number of rental
        :return:
        """
        return self.api_call('rental', {'method': 'detail', 'id': str(rental_id)})

    def rent_rig(self, rentalprofile, hours, rig_id):
        """
        :param rig_id: id
        :return: Returns the detail of rig_id
        """
        return self.api_call('rigs', {'method': 'rent', 'profileid': str(rentalprofile), 'length':str(hours), 'id': str(rig_id)})

    def rig_detail(self, rig_id):
        """
        :param rig_id: id
        :return: Returns the detail of rig_id
        """
        return self.api_call('rigs', {'method': 'detail', 'id': str(rig_id)})

    def rig_list(self, min_hash=0, max_hash=0, min_cost=0, max_cost=0, rig_type='scrypt', showoff='no', order=None,
                 orderdir=None, page=None):
        """
        :param min_hash:
        :param max_hash:
        :param min_cost:
        :param max_cost:
        :param rig_type:
        :param showoff:
        :param order: order is one of 'price','hashrate','minhrs','maxhrs','rating','name'
        :param orderdir: orderdir is one of 'asc','desc'
        :return:
        page for more pages
        """
        params = {'method': 'list', 'type': str(rig_type), 'showoff': str(showoff)}
        if (float(min_hash) > 0):
            params.update({'min_hash': str(min_hash)})
        if (float(max_hash) > 0):
            params.update({'max_hash': str(max_hash)})
        if (float(min_cost) > 0):
            params.update({'min_cost': str(min_cost)})
        if (float(max_cost) > 0):
            params.update({'max_cost': str(max_cost)})
        if order is not None:
            params.update({'order': str(order)})
        if orderdir is not None:
            params.update({'orderdir': str(orderdir)})
        if page is not None:
            params.update({'page': str(page)})
        return self.api_call('rigs', params)

    def rig_update(self, rig_id=None, rig_name=None, rig_status=None, hashrate=None, hash_type=None, price=None,
                   min_hours=None, max_hours=None):
        """
        :param rig_id:
        :param rig_name:
        :param rig_status:
        :param hashrate:
        :param hash_type:
        :param price:
        :param min_hours:
        :param max_hours:
        :return:
        """
        if rig_id is not None:
            params = {'method': 'update', 'id': str(rig_id)}
        else:
            return 'Must specify rig ID'
        if rig_name is not None:
            params.update({'name': str(rig_name)})
        if rig_status is not None:
            if str(rig_status).lower() == 'available':
                params.update({'status': 'available'})
            elif str(rig_status).lower() == 'disabled':
                params.update({'status': 'disabled'})
            else:
                return "Unknown rig Status of: " + str(rig_status) + ". Use available or disabled"
        if price is not None:
            params.update({'price': str(price)})
        if min_hours is not None:
            params.update({'min_hours': str(min_hours)})
        if max_hours is not None:
            params.update({'max_hours': str(max_hours)})
        if hashrate is not None:
            params.update({'hashrate': str(hashrate)})
        if hash_type is not None:
            if hashrate is not None:
                params.update({'hash_type': str(hash_type)})
            else:
                return 'Must define hashrate when hash_type is defined'
        return self.api_call('rigs', params)




#!/usr/bin/python
# -*- coding: UTF-8 -*-

import json
import urllib2
import mrrapi
import ConfigParser
import os
import sys
from datetime import datetime, timedelta
import requests
from optparse import OptionParser
from inspect import currentframe
from pytz import timezone

debug = False
config = ConfigParser.ConfigParser()
PoolPickerIgnore = ['AltMining.Farm', 'MagicPool']
ppa = 1.1  # When rig is available, add 25% above max poolpicker payout
ppr = 1.1  #    When rig is rented, add 35% above max poolpicker payout
mrrrigs = {}
mrrprices = []

for loc in os.curdir, os.path.expanduser("~"), os.path.expanduser("~/.mrrapi"), os.path.expanduser("~/mrrapi"):
    try:
        with open(os.path.join(loc,"mrrapi.cfg")) as source:
            config.readfp(source)
            if debug:
                print "DEBUG: Using %s for config file" % (str(source.name))
    except IOError:
        pass

mkey = config.get('MRRAPIKeys','key')
msecret = config.get('MRRAPIKeys','secret')

def lineno():
    cf = currentframe()
    return cf.f_back.f_lineno

mapi = mrrapi.api(mkey,msecret)
reload(sys)
sys.setdefaultencoding('utf-8')
#helper function to format floats
def ff(f):
    return format(f, '.8f')

#helper function to format floats
def ff12(f):
    return format(f, '.12f')

def getPoolPickerAlgo(algo='ScryptN'):
    global algobtc, poolbtc
    algobtc = []
    poolbtc = {}
    dfmt = '%Y-%m-%d'
    nowTime = datetime.now(timezone('EST5EDT')).strftime(dfmt)
    yDate = (datetime.now() - timedelta(days=1)).strftime(dfmt)
    if debug:
        print " Looking for Date: " + nowTime
    layout = "{0:>45}{1:>20}"
    url = "http://poolpicker.eu/api"
    res = requests.get(url, verify=False)
    if (requests.__version__.split('.')[0] > 0):  #Detect old version of requests used by distros
        tr = res.json()
    else:
        tr = res.json
    if verbose:
        print(layout.format(" Pool Name ", "Payout "))
    for x in tr['pools']:
        if x['profitability'].has_key(algo):  # Make sure this pool has selected algo
            if x['profitability'][algo][0]['date'] == nowTime or x['profitability'][algo][0]['date'] == yDate:  # Look at today only
                if str(x['name']) not in PoolPickerIgnore:  # pools to ignore
                    if str(algo) == 'SHA256':  # PP reports sha256 in THs
                        algobtc.append(float(x['profitability'][algo][0]['btc']) / 10 ** 6)  #bring TH down to MH
                        poolbtc[str(x['name'])] = float(x['profitability'][algo][0]['btc']) / 10 ** 6
                        if verbose:
                            print(layout.format(str(x['name']),
                                                str(round(float(x['profitability'][algo][0]['btc']) / 10 ** 6, 12))))
                    elif str(algo) == 'Keccak':
                        algobtc.append(float(x['profitability'][algo][0]['btc']) / 10 ** 3)  #bring GH down to MH
                        poolbtc[str(x['name'])] = float(x['profitability'][algo][0]['btc']) / 10 ** 3
                        if verbose:
                            print(layout.format(str(x['name']),
                                                str(round(float(x['profitability'][algo][0]['btc']) / 10 ** 3, 12))))
                    else:
                        algobtc.append(float(x['profitability'][algo][0]['btc']))
                        poolbtc[str(x['name'])] = float(x['profitability'][algo][0]['btc'])
                        if verbose:
                            print(
                            layout.format(str(x['name']), str(round(float(x['profitability'][algo][0]['btc']), 10))))
            else:
                if debug:
                    print "Ignoring pool " + str(x['name']) + " due to a past date of " + str(
                        x['profitability'][algo][0]['date'])
    if verbose:
        print(layout.format(" ---------------", "  ----------"))
    if len(algobtc) > 0:
        algobtc.sort()
        if verbose:
            print(layout.format(" Max Payout", round(max(algobtc), 8)))
        if debug:
            print algobtc
            print poolbtc
        return max(algobtc)
    else:
        print "No Pricing available"
        return 1


def getmrrlow(ignoreFirstrigs=0, min_price=0):
    global mrrrigs, mrrprices
    mrrpp = []
    # Get a list of rigs above 10MHs and above min_price of rig_type
    mrrp = mapi.rig_list(10, 0, min_price, rig_type=mrralgo)
    if (str(mrrp['success'] == 'True') and len(mrrp['data']['records']) > 0):  #make sure we have valid data
        for x in mrrp['data']['records']:
            if int(x['id']) not in mrrdevices:  #make sure it is not my rig
                if debug:
                    print x
                if str(x['status']).lower() == 'available':  #only compare available rigs
                    if float(x['rating']) > 4.0:  #only compare highly rated rigs
                        mrrrigs.update({int(x['id']): {'hashrate': float(x['hashrate']), 'price': float(x['price'])}})
                        mrrpp.append(float(x['price']))
                    elif debug:
                        print "Ignoring rig: " + str(x['id']) + " With a rating of " + str(x['rating']) + " for " + str(
                            x['name'])
        for e in mrrpp:
            if e not in mrrprices:
                mrrprices.append(e)
        mrrprices.sort()
        if len(mrrprices) > ignoreFirstrigs:
            if debug:
                print mrrprices[ignoreFirstrigs - 1]
            return mrrprices[ignoreFirstrigs - 1]
        elif len(mrrprices) > 0:
            print "WARNING: " + str(len(mrrprices)) + " prices instead of " + str(ignoreFirstrigs) + " asked for. "
            ignoreFirstrigs = len(mrrprices) - 1
            if debug:
                print mrrprices[ignoreFirstrigs]
            return mrrprices[ignoreFirstrigs]
        else:
            print "Problem with pricing length"
            return 1
    else:
        print "MRR Data failure or no rigs in specs"
        return 1


def setRigPrice(rigId, setPrice, rigDetail=None):
    if rigDetail is not None:
        if float(rigDetail['data']['price']) != float(setPrice):
            if verbose:
                print "Changing rig " + str(rigDetail['data']['id']) + " price from: " + str(
                    float(rigDetail['data']['price'])) + " to " + str(setPrice)
            mapi.rig_update(str(rigDetail['data']['id']), price=str(setPrice))
        else:
            if verbose:
                print "Rig " + str(rigDetail['data']['id']) + " already at " + str(setPrice)
    else:
        if verbose:
            print "Setting Rig " + str(rigId) + " price: " + str(setPrice)
        mapi.rig_update(str(rigId), price=str(setPrice))


def updatemyRigsPrices(percenta, percentr, setPrice, ppPrice):
    """
    :param percenta: Multiplier for max PoolPicker Price when rig available
    :param percentr: Multiplier for max PoolPicker Price when rig is rented
    :param setPrice: Lowest setPrice to set rig. Lowest rate you will accept
    :param ppPrice: Price from poolpicker or other function. this will be multiplied by percent a and r
    :return:
    """
    for x in mrrdevices:
        t = mapi.rig_detail(x)
        if debug:
            print t
        if str(t['data']['status']) == 'available':
            if setPrice > (ppPrice * percenta):
                setRigPrice(x, setPrice, t)
            else:
                setRigPrice(x, (ppPrice * percenta), t)
        elif str(t['data']['status']) == 'rented':
            if setPrice > (ppPrice * percentr):
                setRigPrice(x, setPrice, t)
            else:
                setRigPrice(x, (ppPrice * percentr), t)
        else:
            if setPrice > (ppPrice * percentr):
                setRigPrice(x, setPrice, t)
            else:
                setRigPrice(x, (ppPrice * percentr), t)


def calculateMaxIncomeA():
    global outcome, mhash
    rentalfee = float(0.035)
    outcome = float(0)
    mhash = float(0)
    layout = "{0:>65}{1:>10}{2:>10}{3:>15}{4:>14}"
    print(layout.format("  Device Name  ", " Speed ", "Price  ", "Daily income", "Rented? "))
    for x in mrrdevices:
        t = mapi.rig_detail(x)
        rigstat = "available"
        if (t['success'] == True):
            mhashrate = float(float(t['data']['hashrate']['advertised']) / (1000000.0))
            mhash += mhashrate
            dailyprice = mhashrate * float(t['data']['price']) * (1.0 - rentalfee)
            if (str(t['data']['status']) == 'rented'):
                aih = float(t['data']['available_in_hours'])
                rigstat = "R "
                if 0.1 < aih < 10.0:
                    rigstat += " "
                rigstat += str(aih) + " hrs"
            elif (str(t['data']['status']) == 'unavailable'):
                rigstat = "disabled"
            print(
            layout.format(str(t['data']['name']), str(mhashrate) + " MH", str(round(float(t['data']['price']), 6)),
                          str(round(dailyprice, 8)), rigstat))
            outcome += dailyprice
        if debug:
            print t


def printCalcs():
    btc_usd = getBTCValue()

    #get the max payout from poolpicker
    ppmax = getPoolPickerAlgo(ppalgo)
    # you can replace getPoolPicker with your own function that returns the highest paying pool price

    # the getmrrlow takes 2 arguments
    #  number of lowest prices to ignore
    #  poolpicker max payout
    mrrlow = getmrrlow(3, ppmax)

    #print "PoolPicker Max: " + str(ppmax)
    print "MRR Lowest    : " + str(mrrlow)
    #The following command triggers all of the work.
    # There are four main argument to updateMyRigsPrices
    #  ppa is set at top of file
    #  ppr is set at top of file
    #  Lowest price we will set
    #  Highest payout on poolpicker
    updatemyRigsPrices(ppa, ppr, mrrlow, ppmax)

    calculateMaxIncomeA()
    mrrdaily = outcome - 0.0002

    print "Total Hashing power: " + str(mhash)
    print "MRR BTC: " + str(mrrdaily) + " USD: " + str(mrrdaily * btc_usd)
    #print "Max weekly perfect conditions: ",
    #print (outcome - 0.0002) * btc_usd * 7
    #print "Likely weekly rentals (90%): " + str((0.9 * outcome - 0.0002) * btc_usd * 7)
    #print "CM Weekly: " + str(cmdaily * btc_usd * 7)

def printMCalcs(setPrice):
    btc_usd = getBTCValue()
    updatemyRigsPrices(1, 1, setPrice, setPrice)

    calculateMaxIncomeA()
    mrrdaily = outcome - 0.0002

    print "Total Hashing power: " + str(mhash)
    print "MRR BTC: " + str(mrrdaily) + " USD: " + str(mrrdaily * btc_usd)

def getriginfo(rigid):
    #this maps the mrr algo to the poolpicker algo
    algomap = {'sha256': 'SHA256', 'scrypt': 'Scrypt', 'scryptn': 'ScryptN', 'x11': 'X11', 'x13': 'X13', 'x15': 'X15'}
    global rig, ppalgo, mrralgo, mrrdevices
    try:
        rid = int(rigid)
    except:
        return "Must use a number"
    try:
        rig = mapi.rig_detail(rid)
        print rig
        rigtype = rig['data']['type']
        if algomap.has_key(str(rigtype)):
            ppalgo = algomap[str(rigtype)]
            mrrdevices = [rid]
            mrralgo = str(rigtype)
        else:
            print "Unknown algo mapping for %s" % (str(rigtype))
            return "Unknown Algo"
    except:
        return "Connection Error"








def getBTCValue():
    # https://www.bitstamp.net/api/  BTC -> USD
    bitstampurl = "https://www.bitstamp.net/api/ticker/"
    try:
        bsjson = urllib2.urlopen(bitstampurl).read()
        dbstamp_params = json.loads(bsjson)
        btc_usd = float(dbstamp_params['last'])
    except:
        print "Unable to retrieve BTC Value"
        btc_usd = float(1.1)
    return btc_usd

def parsemyrigs(rigs,list_disabled=False):
    """
    :param rigs: pass the raw api return from mrrapi.myrigs()
    :param list_disabled: Boolean to list the disabled rigs
    :return: returns dict by algorithm
    """
    global mrrrigs
    mrrrigs = {}
    # I am not a python programmer, do you know a better way to do this?
    # first loop to create algo keys
    # second loop populates rigs in algo
    for x in rigs['data']['records']:
        mrrrigs.update({str(x['type']): {}})
    for x in rigs['data']['records']:
        if debug:
            print x
        if (list_disabled or str(x['status']) != 'disabled') and not (str(x['name']).__contains__('retired') or str(x['name']).__contains__('test')):
            mrrrigs[str(x['type'])][int(x['id'])] = str(x['name'])
    if debug:
        print mrrrigs
    return mrrrigs

def calculateMaxIncomeAlgo(parsedrigs):
    global mhash
    rentalfee = float(0.03)
    outcome = float(0)
    mhash = float(0)

    namelen = 0

    # Pre-process loop to find longest name
    for algo in parsedrigs:
        algorigs = parsedrigs[algo]
        for x in algorigs:
            nametmp = len(parsedrigs[algo][x])
            if nametmp > namelen:
                namelen = nametmp
            #print x, algo, namelen

    layout = "{0:>" + str(namelen) + "}{1:>10}{2:>10}{3:>13}{4:>17}{5:>14}{6:>14}{7:>10}"
    print(layout.format("  Device Name  ", " Type ", " Speed ","Cur hash 30m","Price  ", "Daily income", "Rented? ","RentID"))

    for algo in parsedrigs:
        algorigs = parsedrigs[algo]
        for x in algorigs:
            rig = mapi.rig_detail(x)
            t = rig['data']
            if debug:
                print t
            rigstat = "available"
            curhash = float(0.0)
            rentid = ''
            mhashrate = float(t['hashrate']['advertised'])/(1000000.0)
            mhash += mhashrate
            admhashrate = nicehash(float(t['hashrate']['advertised'])/(1000000.0))
            dailyprice = mhashrate * float(t['price']) * (1.0 - rentalfee)
            curhash = nicehash(round(float(t['hashrate']['30min'])/10**6,3))
            if (str(t['status']) == 'rented'):
                aih = float(t['available_in_hours'])
                rigstat = "R "
                if 0.1 < aih < 10.0:
                    rigstat += " "
                rigstat += str(aih) + " hrs"
                rentid = str(t['rentalid'])
            elif (str(t['status']) == 'unavailable'):
                rigstat = "disabled"
                outcome -= dailyprice

            print(layout.format(str(t['name']),str(t['type']),str(admhashrate),str(curhash),ff12(float(t['price'])) ,ff(dailyprice), rigstat,rentid))
            outcome += dailyprice

    return outcome

def nicehash(mhashrate):
    mhunit = "MH"
    if 1000 <= mhashrate < 1000000:
        mhunit = "GH"
        mhashrate = round(float(mhashrate/1000),3)
    elif mhashrate >= 1000000:
        mhunit = "TH"
        mhashrate = round(float(mhashrate/1000000),3)
    elif mhashrate >= 1000000000:
        mhunit = "PH"
        mhashrate = round(float(mhashrate/1000000000),3)
    return (str(mhashrate) + " " + mhunit)

def main():
    global debug, verbose
    verbose=False
    parser = OptionParser()
    parser.add_option("-d", "--debug", action="store_true", dest="debug", default=False, help="Show debug output")
    parser.add_option("-v", "--verbose", action="store_true", dest="verbose", default=False, help="Show verbose output")
    parser.add_option("-r", "--rigid", action="store", dest="rigid", help="RigID of rig to set price of", type="long")
    parser.add_option("-p", "--price", action="store", dest="rigprice", help="Price to set of RigID", type="float")
    parser.add_option("-c", "--calculated", action="store_true", dest="calculated", default=False, help="Automatically calculate price based off of payouts")
    (options, args) = parser.parse_args()

    if options.debug:
        debug = True
        print options
    if options.verbose:
        verbose = True
        print options
    if options.rigid is None or (options.rigprice is None and options.calculated is False):
        if options.rigid is None:
            print "ERROR: You must define a rig id to update."
        if (options.rigprice is None and options.calculated is False):
            print "ERROR: You must define a price or use the calculated option"
        sys.exit(1)

    print getriginfo(str(options.rigid))
    if options.calculated:
        printCalcs()
        sys.exit(0)
    elif options.rigprice:
        printMCalcs(options.rigprice)
        sys.exit(0)

    sys.exit(2)

    #myrigs = mapi.myrigs()
    #if myrigs['success'] is not True:
    #    print "Error getting my rig listings"
    #    if str(myrigs['message']) == 'not authenticated':
    #        print 'Make sure you fill in your key and secret that you get from https://www.miningrigrentals.com/account/apikey'
    #else:
    #    prigs = parsemyrigs(myrigs,True)
    #    #print prigs
    #    maxi = calculateMaxIncomeAlgo(prigs)
    #    bal = mapi.getbalance()
    #    btcv = getBTCValue()
    #    print
    #    print "Max income/day : %s BTC. USD: %s" % (str(round(maxi,8) - 0.002),str(round(btcv*(maxi -0.002),2)))
    #    print "Current Balance: %s BTC. USD: %s" % (str(bal['data']['confirmed']),str(round(btcv*float(bal['data']['confirmed']),2)))
    #    print "Pending Balance: %s BTC. USD: %s" % (str(bal['data']['unconfirmed']),str(round(btcv*float(bal['data']['unconfirmed']),2)))


if __name__ == '__main__':
    main()


import json
import urllib2
import mrrapi
import ConfigParser
import os
import sys
from optparse import OptionParser
from inspect import currentframe

debug = False
config = ConfigParser.ConfigParser()

for loc in os.curdir, os.path.expanduser("~"), os.path.expanduser("~/.mrrapi"), os.path.expanduser("~/mrrapi"):
    try:
        with open(os.path.join(loc,"mrrapi.cfg")) as source:
            config.readfp(source)
            if debug:
                print "DEBUG: Using %s for config file" % (str(source.name))
    except IOError:
        pass

mkey = config.get('MRRAPIKeys','key')
msecret = config.get('MRRAPIKeys','secret')

def lineno():
    cf = currentframe()
    return cf.f_back.f_lineno

def getTerminalSize():
    import os
    env = os.environ
    def ioctl_GWINSZ(fd):
        try:
            import fcntl, termios, struct, os
            cr = struct.unpack('hh', fcntl.ioctl(fd, termios.TIOCGWINSZ,
        '1234'))
        except:
            return
        return cr
    cr = ioctl_GWINSZ(0) or ioctl_GWINSZ(1) or ioctl_GWINSZ(2)
    if not cr:
        try:
            fd = os.open(os.ctermid(), os.O_RDONLY)
            cr = ioctl_GWINSZ(fd)
            os.close(fd)
        except:
            pass
    if not cr:
        cr = (env.get('LINES', 25), env.get('COLUMNS', 80))

        ### Use get(key[, default]) instead of a try/catch
        #try:
        #    cr = (env['LINES'], env['COLUMNS'])
        #except:
        #    cr = (25, 80)
    return int(cr[1]), int(cr[0])

mapi = mrrapi.api(mkey,msecret)
debug = False
#helper function to format floats
def ff(f):
    return format(f, '.8f')

#helper function to format floats
def ff12(f):
    return format(f, '.12f')


def getBTCValue():
    # https://www.bitstamp.net/api/  BTC -> USD
    bitstampurl = "https://www.bitstamp.net/api/ticker/"
    try:
        bsjson = urllib2.urlopen(bitstampurl).read()
        dbstamp_params = json.loads(bsjson)
        btc_usd = float(dbstamp_params['last'])
    except:
        print "Unable to retrieve BTC Value"
        btc_usd = float(1.1)
    return btc_usd

def parsemyrigs(rigs,list_disabled=False):
    """
    :param rigs: pass the raw api return from mrrapi.myrigs()
    :param list_disabled: Boolean to list the disabled rigs
    :return: returns dict by algorithm
    """
    global mrrrigs
    mrrrigs = {}
    # I am not a python programmer, do you know a better way to do this?
    # first loop to create algo keys
    # second loop populates rigs in algo
    for x in rigs['data']['records']:
        mrrrigs.update({str(x['type']): {}})
    for x in rigs['data']['records']:
        if debug:
            print x
        if (list_disabled or str(x['status']) != 'disabled') and not (str(x['name']).__contains__('retired') or str(x['name']).__contains__('test')):
            mrrrigs[str(x['type'])][int(x['id'])] = str(x['name'])
    if debug:
        print mrrrigs
    return mrrrigs

def calculateMaxIncomeAlgo(parsedrigs):
    global mhash
    rentalfee = float(0.03)
    outcome = float(0)
    mhash = float(0)

    namelen = 0

    # Pre-process loop to find longest name
    for algo in parsedrigs:
        algorigs = parsedrigs[algo]
        for x in algorigs:
            nametmp = len(parsedrigs[algo][x])
            if nametmp > namelen:
                namelen = nametmp
            #print x, algo, namelen

    layout = "{0:>" + str(namelen) + "}{1:>10}{2:>10}{3:>13}{4:>17}{5:>14}{6:>14}{7:>10}"
    print(layout.format("  Device Name  ", " Type ", " Speed ","Cur hash 30m","Price  ", "Daily income", "Rented? ","RentID"))

    for algo in parsedrigs:
        algorigs = parsedrigs[algo]
        for x in algorigs:
            rig = mapi.rig_detail(x)
            t = rig['data']
            if debug:
                print t
            rigstat = "available"
            curhash = float(0.0)
            rentid = ''
            mhashrate = float(t['hashrate']['advertised'])/(1000000.0)
            mhash += mhashrate
            admhashrate = nicehash(float(t['hashrate']['advertised'])/(1000000.0))
            dailyprice = mhashrate * float(t['price']) * (1.0 - rentalfee)
            curhash = nicehash(round(float(t['hashrate']['30min'])/10**6,3))
            if (str(t['status']) == 'rented'):
                aih = float(t['available_in_hours'])
                rigstat = "R "
                if 0.1 < aih < 10.0:
                    rigstat += " "
                rigstat += str(aih) + " hrs"
                rentid = str(t['rentalid'])
            elif (str(t['status']) == 'unavailable'):
                rigstat = "disabled"
                outcome -= dailyprice

            print(layout.format(str(t['name']),str(t['type']),str(admhashrate),str(curhash),ff12(float(t['price'])) ,ff(dailyprice), rigstat,rentid))
            outcome += dailyprice

    return outcome

def nicehash(mhashrate):
    mhunit = "MH"
    if 1000 <= mhashrate < 1000000:
        mhunit = "GH"
        mhashrate = round(float(mhashrate/1000),3)
    elif mhashrate >= 1000000:
        mhunit = "TH"
        mhashrate = round(float(mhashrate/1000000),3)
    elif mhashrate >= 1000000000:
        mhunit = "PH"
        mhashrate = round(float(mhashrate/1000000000),3)
    return (str(mhashrate) + " " + mhunit)

def main():
    global debug
    parser = OptionParser()
    parser.add_option("-d", "--debug", action="store_true", dest="debug", default=False, help="Show debug output")
    (options, args) = parser.parse_args()

    if options.debug:
        debug = True
        print options
        print getTerminalSize()

    myrigs = mapi.myrigs()
    if myrigs['success'] is not True:
        print "Error getting my rig listings"
        if str(myrigs['message']) == 'not authenticated':
            print 'Make sure you fill in your key and secret that you get from https://www.miningrigrentals.com/account/apikey'
    else:
        prigs = parsemyrigs(myrigs,True)
        #print prigs
        maxi = calculateMaxIncomeAlgo(prigs)
        bal = mapi.getbalance()
        btcv = getBTCValue()
        print
        print "Max income/day : %s BTC. USD: %s" % (str(round(maxi,8) - 0.002),str(round(btcv*(maxi -0.002),2)))
        print "Current Balance: %s BTC. USD: %s" % (str(bal['data']['confirmed']),str(round(btcv*float(bal['data']['confirmed']),2)))
        print "Pending Balance: %s BTC. USD: %s" % (str(bal['data']['unconfirmed']),str(round(btcv*float(bal['data']['unconfirmed']),2)))


if __name__ == '__main__':
    main()


import os

try:
    from setuptools import setup, find_packages # Always prefer setuptools over distutils
except ImportError:
    from distutils.core import setup

here = os.path.abspath(os.path.dirname(__file__))
# Get the long description from the relevant file
def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name='mrrapi',
    version='0.3.4',
    url='https://github.com/jcwoltz/mrrapi',
    description='MinigRigRentals.com python API integration',
    long_description=read('README.rst') + '\n\n' + read('CHANGES.txt'),
    classifiers=[
        "Development Status :: 4 - Beta",
        "Programming Language :: Python",
        "Topic :: Office/Business :: Financial"
    ],
    author='jcwoltz',
    author_email='jwoltz@gmail.com',
    keywords='mrr miningrigrentals api bitcoin',
    packages=find_packages(exclude=['contrib', 'example*', 'docs', 'tests*']),
    install_requires=['requests'],
    test_suite="mrrapi",
    entry_points={
        'console_scripts': [
            'listmyrigs = tools.list_myrigs:main',
            'updaterigprice = tools.updaterigprice:main'
        ]
    }
)
